@@ -6,8 +6,8 @@ from typing import Iterable, Any
 import requests
 from bs4 import BeautifulSoup
 
-from Err import TransformError
-from transformers.Jsi18n import Jsi18n
+from .Err import TransformError
+from .transformers.Jsi18n import Jsi18n
 
 statement = 'End : {}, IO File {}'
 
@@ -246,7 +246,7 @@ class GoogleTranslationSheet:
         self._readerEngine = module_reader
         return self
 
-    def builderMeta(self, url: str, tabname: str) -> "lib":
+    def builderMeta(self, url: str, tabname: str = "") -> "lib":
         """
         this is the required for the basic meta information for loading google sheet
         :param url:
